{% extends base_template|default:"handyhelpers/handyhelpers_base.htm" %}
{% load static %}

{% block local_head %}
    <script src="{% static 'node_modules/chart.js/dist/Chart.bundle.min.js' %}"></script>
    <style>
        a:hover {
            text-decoration: none;
        }
    </style>
{% endblock local_head %}

{% block content %}
    {% include 'handyhelpers/report/annual_progress_content.htm' %}
{% endblock content %}
